==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/base/FoodItem.java <==
package cc.thonly.reverie_dreams.item.base;

import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import cc.thonly.reverie_dreams.data.FoodProperty;

import java.util.*;
import net.minecraft.class_1309;
import net.minecraft.class_1702;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4174;

public class FoodItem extends class_1792 {

    public FoodItem(class_1793 settings) {
        this(0, 0f, settings);
    }

    public FoodItem(List<FoodProperty> foodProperties, class_1793 settings) {
        super(settings.method_57349(RDDataComponentTypes.FOOD_PROPERTIES, foodProperties.stream().map(FoodProperty::getId).map(class_2960::toString).toList()));
    }

    public FoodItem(List<FoodProperty> foodProperties, Integer nutrition, Float saturation, class_1793 settings) {
        this(
                settings.method_19265(new class_4174.class_4175()
                                .method_19238(nutrition + 2)
                                .method_19237(saturation + 2)
                                .method_19242()
                        )
                        .method_57349(RDDataComponentTypes.FOOD_PROPERTIES, foodProperties.stream().map(FoodProperty::getId).map(class_2960::toString).toList()));
    }

    public FoodItem(Integer nutrition, Float saturation, class_1793 settings) {
        super(settings
                .method_19265(new class_4174.class_4175()
                        .method_19238(nutrition + 2)
                        .method_19237(saturation + 2)
                        .method_19242()
                ));
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            Set<FoodProperty> foodProperties = new HashSet<>(FoodProperty.getFromItemStack(stack));
            Set<FoodProperty> foodPropertiesFromComponent = new HashSet<>(FoodProperty.getFromItemStackComponent(stack));

            Set<FoodProperty> allProperties = new HashSet<>(foodProperties);
            allProperties.addAll(foodPropertiesFromComponent);

            for (FoodProperty foodProperty : allProperties) {
                foodProperty.use(serverWorld, user);
            }
            if (user instanceof class_3222 player) {
                class_1702 hungerManager = player.method_7344();
                allProperties.forEach((property) -> hungerManager.method_7585(1, 2));
            }
        }
        return super.method_7861(stack, world, user);
    }


//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        super.appendTooltip(stack, context, displayComponent, textConsumer, type);
//        List<FoodProperty> foodProperties = FoodProperty.getFromItemStackComponent(stack);
//        List<FoodProperty> foodIngredientProperties = FoodProperty.getIngredientProperties(this);
//        Set<FoodProperty> foodPropertyList = new HashSet<>();
//        foodPropertyList.addAll(foodProperties);
//        foodPropertyList.addAll(foodIngredientProperties);
//        if (!foodPropertyList.isEmpty()) {
//            textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.food_properties")));
//        }
//        for (FoodProperty foodProperty : foodPropertyList) {
//            textConsumer.accept(Text.empty().append(FoodProperty.getDisplayPrefix(stack, foodProperty)).append(foodProperty.getTooltip()));
//        }
//
//    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/base/FoodItem.java <==
package cc.thonly.reverie_dreams.item.base;

import cc.thonly.reverie_dreams.data.FoodProperty;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponents;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import net.minecraft.class_1309;
import net.minecraft.class_1702;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4174;

public class FoodItem extends class_1792 {

    public FoodItem(class_1793 settings) {
        this(0, 0f, settings);
    }

    public FoodItem(List<FoodProperty> foodProperties, class_1793 settings) {
        super(settings.method_57349(RDDataComponents.FOOD_PROPERTIES, foodProperties.stream().map(FoodProperty::getId).map(class_2960::toString).toList()));
    }

    public FoodItem(List<FoodProperty> foodProperties, Integer nutrition, Float saturation, class_1793 settings) {
        this(
                settings.method_19265(new class_4174.class_4175()
                                .method_19238(nutrition + 2)
                                .method_19237(saturation + 2)
                                .method_19242()
                        )
                        .method_57349(RDDataComponents.FOOD_PROPERTIES, foodProperties.stream().map(FoodProperty::getId).map(class_2960::toString).toList()));
    }

    public FoodItem(Integer nutrition, Float saturation, class_1793 settings) {
        super(settings
                .method_19265(new class_4174.class_4175()
                        .method_19238(nutrition + 2)
                        .method_19237(saturation + 2)
                        .method_19242()
                ));
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            Set<FoodProperty> foodProperties = new HashSet<>(FoodProperty.getFromItemStack(stack));
            Set<FoodProperty> foodPropertiesFromComponent = new HashSet<>(FoodProperty.getFromItemStackComponent(stack));

            Set<FoodProperty> allProperties = new HashSet<>(foodProperties);
            allProperties.addAll(foodPropertiesFromComponent);

            for (FoodProperty foodProperty : allProperties) {
                foodProperty.use(serverWorld, user);
            }
            if (user instanceof class_3222 player) {
                class_1702 hungerManager = player.method_7344();
                allProperties.forEach((property) -> hungerManager.method_7585(1, 2));
            }
        }
        return super.method_7861(stack, world, user);
    }


//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        super.appendTooltip(stack, context, displayComponent, textConsumer, type);
//        List<FoodProperty> foodProperties = FoodProperty.getFromItemStackComponent(stack);
//        List<FoodProperty> foodIngredientProperties = FoodProperty.getIngredientProperties(this);
//        Set<FoodProperty> foodPropertyList = new HashSet<>();
//        foodPropertyList.addAll(foodProperties);
//        foodPropertyList.addAll(foodIngredientProperties);
//        if (!foodPropertyList.isEmpty()) {
//            textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.food_properties")));
//        }
//        for (FoodProperty foodProperty : foodPropertyList) {
//            textConsumer.accept(Text.empty().append(FoodProperty.getDisplayPrefix(stack, foodProperty)).append(foodProperty.getTooltip()));
//        }
//
//    }
}
